@@ -2,6 +2,9 @@ from .primitives.Line import Line
 from .primitives.BaseShape import BaseShape
 from .primitives.Ellipse import Circle, Ellipse, Point, Arc
 from .primitives.Rectangle import Rectangle, Square
+from .primitives.Rectangle import Rectangle, Square
+from .primitives.Group import Group
+from .primitives.Text import Text
 from .enviornment.Canvas import _Canvas
 from .helpers.CircleMath import CircleMath
 # from .primitives.TextLine import TextLine
@@ -25,9 +28,11 @@ __all__ = [
 	'Point',
 	'Rectangle',
 	'Square',
+	'Group',
 	'CircleMath',
 	'BaseShape',
 	'Canvas',
+	'Text'
 ]
 
 
