@@ -1,6 +1,7 @@
 # this should mirror what is available in an svg
 import math
 import sys
+import uuid
 
 import numpy as np
 
@@ -9,9 +10,9 @@ from ..helpers.CircleMath import CircleMath
 import sys
 
 class BaseShape(object):
-	'''All provided primatives inherit from this class. If a user wants to make thier own primative, its reccomended to
+	'''All provided primitives inherit from this class. If a user wants to make their own primitive, its recommended to
 	inherit from this class so the new primative is added to the draw queue.'''
-	def __init__(self, **kwargs):
+	def __init__(self,**kwargs):
 		self._vertices = np.array([])
 		self._fill_color='none'
 		self._stroke_color='black'
@@ -21,7 +22,10 @@ class BaseShape(object):
 
 		self.is_circle=False
 		self.is_arc=False
-		self.is_multipath = False
+		self.is_group = False
+		self.is_text = False
+
+		self.id = str(uuid.uuid4())
 
 		for k,v in kwargs.items():
 			if hasattr(self, k):
@@ -33,11 +37,11 @@ class BaseShape(object):
 		_Canvas.draw_queue.append(self)
 
 
-	def __str__(self):
-		return f'<{__class__} fill_color: {self.fill_color}>'
-
-	def __repr__(self):
-		return f'<{__class__} fill_color: {self.fill_color}>'
+	# def __str__(self):
+	# 	return f'<{__class__} fill_color: {self.fill_color}>'
+	#
+	# def __repr__(self):
+	# 	return f'<{__class__} fill_color: {self.fill_color}>'
 
 	@property
 	def fill_color(self):
@@ -218,9 +222,9 @@ class BaseShape(object):
 
 
 	def rotate(self, theta, origin=None, axis=np.array([0, 0, 1])):
-		"""Rotate the display by the given angle along the given axis.
+		"""Rotate the shape by the given angle along the given axis.
 
-		:param theta: The angle by which to rotate (in radians)
+		:param theta: The angle by which to rotate (in degrees)
 		:type theta: float
 
 		:param axis: The axis along which to rotate (defaults to the z-axis)
@@ -283,9 +287,9 @@ class BaseShape(object):
 
 
 	def rotate_x(self, theta):
-		"""Rotate the view along the x axis.
+		"""This is a convenience function to rotate the shape along the x axis.
 
-		:param theta: angle by which to rotate (in radians)
+		:param theta: The angle by which to rotate (in degrees)
 		:type theta: float
 
 		:returns: The rotation matrix used to apply the transformation.
@@ -295,9 +299,9 @@ class BaseShape(object):
 		self.rotate(theta, axis=np.array([1, 0, 0]))
 
 	def rotate_y(self, theta):
-		"""Rotate the view along the y axis.
+		"""This is a convenience function to rotate the shape along the y axis.
 
-		:param theta: angle by which to rotate (in radians)
+		:param theta: The angle by which to rotate (in degrees)
 		:type theta: float
 
 		:returns: The rotation matrix used to apply the transformation.
@@ -307,9 +311,9 @@ class BaseShape(object):
 		self.rotate(theta, axis=np.array([0, 1, 0]))
 
 	def rotate_z(self, theta):
-		"""Rotate the view along the z axis.
+		"""This is a convenience function to rotate the shape along the z axis.
 
-		:param theta: angle by which to rotate (in radians)
+		:param theta:The angle by which to rotate (in degrees)
 		:type theta: float
 
 		:returns: The rotation matrix used to apply the transformation.
