@@ -1,9 +1,10 @@
 from .BaseShape import BaseShape
 
-from typing import Tuple
+from typing import Tuple, List
+
 class Line(BaseShape):
 	'''This is how you create a line with two or more vertices'''
-	def __init__(self, vertices:[Tuple]=None, **kwargs):
+	def __init__(self, vertices:List[Tuple]=None, **kwargs):
 		super().__init__(**kwargs)
 		if vertices:
 			for (x,y) in vertices:
