@@ -1,12 +1,13 @@
 from .BaseShape import BaseShape
 
-#TODO: Consider if we want to implement rounded edges:
+# TODO: Consider if we want to implement rounded edges:
 # https://developer.mozilla.org/en-US/docs/Web/SVG/Element/rect
 
+
 class Rectangle(BaseShape):
 	def __init__(self, c_x, c_y, width, height, **kwargs):
-		'''
-		Creates a Rectangle Primative
+		"""
+		Creates a Rectangle Primitive
 
 		Parameters
 		----------
@@ -19,14 +20,15 @@ class Rectangle(BaseShape):
 		:param width:
 		:param height:
 		:param kwargs:
-		'''
+		"""
+
 		super().__init__(**kwargs)
 		self.c_x = c_x
 		self.c_y = c_y
 		self.width = width
 		self.height = height
 
-		self.close_path=True
+		self.close_path = True
 
 		# top left
 		t_l_x = c_x - (width/2)
@@ -36,7 +38,7 @@ class Rectangle(BaseShape):
 		t_r_x = c_x + (width/2)
 		t_r_y = c_y - (height/2)
 
-		#bottom right
+		# bottom right
 		b_r_x = c_x + (width / 2)
 		b_r_y = c_y + (height / 2)
 
@@ -51,10 +53,11 @@ class Rectangle(BaseShape):
 		self.add_vertex(b_r_x, b_r_y)
 		self.add_vertex(b_l_x, b_l_y)
 
+
 class Square(Rectangle):
-	def __init__(self, c_x:int, c_y:int, width, **kwargs):
+	def __init__(self, c_x: int, c_y: int, width, **kwargs):
 		"""
-		Create a square primative
+		Create a square primitive
 
 		:param c_x: center of square x coordinate
 		:param c_y: center of square y coordinate
@@ -62,5 +65,4 @@ class Square(Rectangle):
 		:param kwargs: style dict
 		"""
 
-
-		super().__init__(c_x, c_y, width, width,**kwargs)
+		super().__init__(c_x, c_y, width, width, **kwargs)
